@@ -1,9 +1,7 @@
 package Lemonldap::NG::Portal::Simple;
 
-use 5.008004;
 use strict;
 use warnings;
-use Carp;
 
 use Exporter 'import';
 
@@ -42,8 +40,7 @@ our %EXPORT_TAGS = (
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our @EXPORT =
-  qw( PE_OK PE_SESSIONEXPIRED PE_FORMEMPTY PE_WRONGMANAGERACCOUNT PE_USERNOTFOUND PE_BADCREDENTIALS
+our @EXPORT = qw( PE_OK PE_SESSIONEXPIRED PE_FORMEMPTY PE_WRONGMANAGERACCOUNT PE_USERNOTFOUND PE_BADCREDENTIALS
   PE_LDAPCONNECTFAILED PE_LDAPERROR PE_APACHESESSIONERROR PE_FIRSTACCESS PE_BADCERTIFICATE import );
 
 sub new {
@@ -102,7 +99,7 @@ sub error {
     else {
         @message = (
             'Everything is OK',
-'Your connection has expired; You must to be authentified once again',
+            'Your connection has expired; You must to be authentified once again',
             'User and password fields must be filled',
             'Wrong directory manager account or password',
             'User not found in directory',
@@ -119,8 +116,7 @@ sub error {
 sub process {
     my ($self) = @_;
     $self->{error} = PE_OK;
-    foreach my $sub
-      qw(controlUrlOrigin extractFormInfo formateParams formateFilter
+    foreach my $sub qw(controlUrlOrigin extractFormInfo formateParams formateFilter
       connectLDAP bind search setSessionInfo setGroups authenticate store unbind
       buildCookie log autoRedirect) {
         if ( $self->{$sub} )
@@ -219,8 +215,7 @@ sub bind {
     my $self = shift;
     $self->connectLDAP unless ( $self->{ldap} );
     return PE_WRONGMANAGERACCOUNT
-      unless (
-        &_bind( $self->{ldap}, $self->{managerDn}, $self->{managerPassword} ) );
+      unless ( &_bind( $self->{ldap}, $self->{managerDn}, $self->{managerPassword} ) );
     PE_OK;
 }
 
@@ -250,8 +245,7 @@ sub setSessionInfo {
     }
     elsif ( ref( $self->{exportedVars} ) eq 'HASH' ) {
         foreach ( keys %{ $self->{exportedVars} } ) {
-            $self->{sessionInfo}->{$_} =
-              $self->{entry}->get_value( $self->{exportedVars}->{$_} ) || "";
+            $self->{sessionInfo}->{$_} = $self->{entry}->get_value( $self->{exportedVars}->{$_} ) || "";
         }
     }
     else {
@@ -287,13 +281,10 @@ sub authenticate {
 sub store {
     my ($self) = @_;
     my %h;
-    eval {
-        tie %h, $self->{globalStorage}, undef, $self->{globalStorageOptions};
-    };
+    eval { tie %h, $self->{globalStorage}, undef, $self->{globalStorageOptions}; };
     return PE_APACHESESSIONERROR if ($@);
     $self->{id} = $h{_session_id};
-    $h{$_} = $self->{sessionInfo}->{$_}
-      foreach ( keys %{ $self->{sessionInfo} } );
+    $h{$_} = $self->{sessionInfo}->{$_} foreach ( keys %{ $self->{sessionInfo} } );
     $h{_utime} = time();
     untie %h;
     PE_OK;
@@ -320,20 +311,22 @@ sub autoRedirect {
             -cookie => $self->{cookie},
             -status => '302 Moved Temporary'
         );
-        print << "EOF";
-<html>
-<head>
-<script language="Javascript">
-function redirect() {
-	document.location.href='$u';
-}
-</script>
-</head>
-<body onload="redirect();">
-	<h2>The document has moved <a href="$u">HERE</a></h2>
-</body>
-</html>
-EOF
+
+        # Remove this lines if your browsers does not support redirections
+        #        print << "EOF";
+        #<html>
+        #<head>
+        #<script language="Javascript">
+        #function redirect() {
+        #	document.location.href='$u';
+        #}
+        #</script>
+        #</head>
+        #<body onload="redirect();">
+        #	<h2>The document has moved <a href="$u">HERE</a></h2>
+        #</body>
+        #</html>
+        #EOF
         exit;
     }
     PE_OK;
@@ -391,7 +384,8 @@ Lemonldap::NG::Portal::Simple - Base module for building Lemonldap::NG compatibl
     print '<input type="hidden" name="url" value="'.$portal->param('url').'">';
     # Next, login and password
     print 'Login : <input name="user"><br>';
-    print 'Password : <input name="pasword" type="password" autocomplete="off">';
+    print 'Password : <input name="password" type="password" autocomplete="off">';
+    print '<input type="submit" value="go" />';
     print '</form>';
   }
 
